@@ -15,15 +15,14 @@ use Carp;
 
 requires 'username', 'password', 'api_key', '_base_uri', 'response_type';
 
-our $VERSION = '1.0.4'; # VERSION
+our $VERSION = '1.0.5'; # VERSION
 # ABSTRACT: Construct Methods For Making Raw LogicBoxes Requests
 
 use Readonly;
-# Create methods to support LogicBoxes API as of 2012-03-02
 Readonly our $API_METHODS => {
     domains => {
         GET => [
-            qw(available suggest-names validate-transfer search customer-default-ns orderid details details-by-name locks tel/cth-details)
+            qw(available suggest-names v5/suggest-names validate-transfer search customer-default-ns orderid details details-by-name locks tel/cth-details)
         ],
         POST => [
             qw(register transfer eu/transfer eu/trade uk/transfer renew modify-ns add-cns modify-cns-name modify-cns-ip delete-cns-ip modify-contact modify-privacy-protection modify-auth-code enable-theft-protection disable-theft-protection tel/modify-whois-pref resend-rfa uk/release cancel-transfer delete restore de/recheck-ns dotxxx/assoication-details)
