@@ -8,7 +8,7 @@ use Data::Validate::Email qw( is_email );
 use Data::Validate::IP qw( is_ipv4 );
 use Data::Validate::URI qw( is_uri );
 
-our $VERSION = '1.0.4'; # VERSION
+our $VERSION = '1.0.5'; # VERSION
 # ABSTRACT: WWW::LogicBoxes Moose Type Library
 
 use MooseX::Types -declare => [qw(
@@ -41,6 +41,8 @@ use MooseX::Types -declare => [qw(
     Contact
     Customer
     Domain
+    DomainAvailability
+    DomainAvailabilities
     DomainRegistration
     DomainTransfer
     PrivateNameServer
@@ -98,6 +100,9 @@ class_type Domain, { class => 'WWW::LogicBoxes::Domain' };
 coerce Domain, from HashRef,
     via { WWW::LogicBoxes::Domain->new( $_ ) };
 
+class_type DomainAvailability, { class => 'WWW::LogicBoxes::DomainAvailability' };
+subtype DomainAvailabilities, as ArrayRef[DomainAvailability];
+
 class_type DomainRegistration, { class => 'WWW::LogicBoxes::DomainRequest::Registration' };
 coerce DomainRegistration, from HashRef,
     via { WWW::LogicBoxes::DomainRequest::Registration->new( $_ ) };
